SQLAlchemy 0.3 Documentation - module sqlalchemy.exceptions

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.7 Last Updated: 04/30/07 00:08:52

### module sqlalchemy.exceptions

### class ArgumentError()

Raised for all those conditions where invalid arguments are sent to constructed objects. This error generally corresponds to construction time state errors.

back to section top

### class AssertionError()

Corresponds to internal state being detected in an invalid state.

back to section top

### class CircularDependencyError()

Raised by topological sorts when a circular dependency is detected

back to section top

### class CompileError()

Raised when an error occurs during SQL compilation

back to section top

### class ConcurrentModificationError()

Raised when a concurrent modification condition is detected.

back to section top

### class DBAPIError()

Something weird happened with a particular DBAPI version.

def __init__(self, message, orig)
back to section top

### class FlushError()

Raised when an invalid condition is detected upon a `flush()`.

back to section top

### class InvalidRequestError()

SQLAlchemy was asked to do something it can't do, return nonexistent data, etc.

This error generally corresponds to runtime state errors.

back to section top

### class NoSuchColumnError()

Raised by `RowProxy` when a nonexistent column is requested from a row.

back to section top

### class NoSuchTableError()

SQLAlchemy was asked to load a table's definition from the database, but the table doesn't exist.

back to section top

### class SQLAlchemyError()

Generic error class.

back to section top

### class SQLError()

Raised when the execution of a SQL statement fails.

Includes accessors for the underlying exception, as well as the SQL and bind parameters.

def __init__(self, statement, params, orig)
back to section top

### class TimeoutError()

Raised when a connection pool times out on getting a connection.

back to section top